distribute_tasks

Function distribute_tasks 

pub async fn distribute_tasks(
    config: TaskDistributorConfig,
    strategy: DistributionStrategy,
)
Task distributor. Spawns a background task that distributes tasks to workers according to the chosen strategy, handles cooldowns, and sends end/break signals.

Arguments

  • config - TaskDistributorConfig with all necessary parameters
  • strategy - How tasks should be distributed (Broadcast, RoundRobin, or Discovery)