pub async fn distribute_tasks(
config: TaskDistributorConfig,
strategy: DistributionStrategy,
)Expand description
Task distributor. Spawns a background task that distributes tasks to workers according to the chosen strategy, handles cooldowns, and sends end/break signals.
Arguments
config- TaskDistributorConfig with all necessary parametersstrategy- How tasks should be distributed (Broadcast, RoundRobin, or Discovery)