pub struct TaskDistributorConfig {
pub m_id: u32,
pub hitlist: Vec<Address>,
pub measurement: Arc<RwLock<Option<MeasurementState>>>,
pub workers: Arc<Mutex<Vec<WorkerSender<Result<Instruction, Status>>>>>,
pub probing_rate: u32,
pub probing_rate_interval: Interval,
pub number_of_probing_workers: usize,
pub worker_interval: u64,
pub nprobes: u32,
pub probe_interval: u64,
pub is_prefix_hitlist: bool,
}Fields
m_id: u32ID of the measurement this distributor belongs to
hitlist: Vec<Address>Target addresses to probe
measurement: Arc<RwLock<Option<MeasurementState>>>All per-measurement state. None when idle.
workers: Arc<Mutex<Vec<WorkerSender<Result<Instruction, Status>>>>>Shared list of worker senders, updated on reconnect.
probing_rate: u32Number of tasks to send per interval (equal to probing rate)
probing_rate_interval: IntervalInterval at which to send tasks
number_of_probing_workers: usizeNumber of probing workers
worker_interval: u64Inter-worker interval in seconds between workers
nprobes: u32Number of times to repeat each measurement probe (discovery probes are always sent once)
probe_interval: u64Inter-probe interval in seconds between repeated probes
is_prefix_hitlist: boolMeasure multiple targets pre prefix, skip targets of already-resolved prefixes